================
Citing PESummary
================

If you have used PESummary as part of a project that leads to a scientific
publication, please add the following acknowledge statement:

.. code-block:: console

    Some of the results in this paper have been derived using the ``pesummary``
    package~\cite{pesummary}

The citation in various formats is given below:

.. tabbed:: BibTeX

    .. code-block:: bibtex

        @article{Hoy:2020vys,
            author = "Hoy, Charlie and Raymond, Vivien",
            title = "{PESummary: the code agnostic Parameter Estimation Summary page builder}",
            eprint = "2006.06639",
            archivePrefix = "arXiv",
            primaryClass = "astro-ph.IM",
            reportNumber = "LIGO-P2000156",
            doi = "10.1016/j.softx.2021.100765",
            journal = "SoftwareX",
            volume = "15",
            pages = "100765",
            year = "2021"
        }

.. tabbed:: LaTeX (EU)

    .. code-block::

        %\cite{Hoy:2020vys}
        \bibitem{Hoy:2020vys}
        C.~Hoy and V.~Raymond,
        %``PESummary: the code agnostic Parameter Estimation Summary page builder,''
        SoftwareX \textbf{15} (2021), 100765
        doi:10.1016/j.softx.2021.100765
        [arXiv:2006.06639 [astro-ph.IM]].

.. tabbed:: LaTeX (US)

    .. code-block::

        %\cite{Hoy:2020vys}
        \bibitem{Hoy:2020vys}
        C.~Hoy and V.~Raymond,
        %``PESummary: the code agnostic Parameter Estimation Summary page builder,''
        SoftwareX \textbf{15}, 100765 (2021)
        doi:10.1016/j.softx.2021.100765
        [arXiv:2006.06639 [astro-ph.IM]].
